package
Version:
v0.0.0-...-36127f2
Opens a new window with list of versions in this module.
Published: Nov 28, 2023
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type DbPing struct {
ConnStr string `json:"connStr"`
ConnType string `json:"connType"`
}
type DefaultErrorResponse struct {
Message string `json:"message"`
Status int `json:"status"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.